@@ -1,20 +1,21 @@
 #' @title Background Noise and Soundscape Power Index
 #'
-#' @description Compute the Background Noise and Soundscape Power values of an audio using Towsey 2017 methodology
+#' @description Calculate the Background Noise and Soundscape Power values of a single audio using the methodology proposed in Towsey 2017
 #'
-#' @param soundfile tuneR Wave object or path to a valid audio
-#' @param channel channel where the background noise values will be extract from. Available channels are: `"stereo"`, `"mono"`, `"left"` or `"right"`. Defaults to `"stereo"`.
-#' @param timeBin size (in seconds) of the time bin. Defaults to `60`.
-#' @param dbThreshold minimum allowed value of dB for the spectrograms. Defaults to `-90`, as set by Towsey 2017.
-#' @param targetSampRate sample rate of the audios. Defaults to `NULL` to not change the sample rate. This argument is only used to down sample the audio.
-#' @param wl window length of the spectrogram. Defaults to `512`.
-#' @param window window used to smooth the spectrogram. Defaults to `signal::hammning(wl)`. Switch to `signal::hanning(wl)` if to use hanning instead.
+#' @param soundfile tuneR Wave object or path to a valid audio file
+#' @param channel channel where the metric values will be extract from. Available channels are: `"stereo"`, `"mono"`, `"left"` or `"right"`. Defaults to `"stereo"`
+#' @param timeBin size (in seconds) of the time bin. Set to `NULL` to use the entire audio as a single bin. Defaults to `60`
+#' @param dbThreshold minimum allowed value of dB for the spectrograms. Defaults to `-90`, as set by Towsey 2017
+#' @param targetSampRate desired sample rate of the audios.  This argument is only used to down sample the audio. If `NULL`, then audio's sample rate remains the same. Defaults to `NULL`
+#' @param wl window length of the spectrogram. Defaults to `512`
+#' @param window window used to smooth the spectrogram. Switch to `signal::hanning(wl)` to use hanning instead. Defaults to `signal::hammning(wl)`
 #' @param overlap overlap between the spectrogram windows. Defaults to `wl/2` (half the window length)
-#' @param histbreaks breaks used to calculate Background Noise. Available breaks are: `"FD"`, `"Sturges`", `"scott"` and `100`. Defaults to `"FD"`.
-#' <br>Can also be set to any number to limit or increase the amount of breaks.
+#' @param histbreaks breaks used to calculate Background Noise. Available breaks are: `"FD"`, `"Sturges"`, `"scott"` or any numeric value (foe example = `100`). Defaults to `"FD"`
 #'
-#' @returns A list containing three objects: The first and second one contains a matrix with the values of Background Noise and Soundscape Power respectively to each time bin and for each frequency window of your soundfile. The third object is the duration in second of your time bins.
-#' @details Background Noise (`BGN`) is an index that measures the most common continuous baseline level of acoustic energy in a frequency window and in a time bin. It was developed by Towsey 2017 using the Lamel et al 1981 algorithm. is calculated by taking the modal value of intensity values in temporal bin c in frequency window f:
+#' @returns This function returns a list containing five objects. The first object (values) contain the values of BGN and POW. The second object (timeBins) contains the durations of each time bin analysed. The third object (sampRate) contains the audio's sampling rate. The fourth and last object (channel) contains the channels used for the calculation of the metric.
+#'
+#' @details Background Noise (`BGN`) is an acoustic metric that measures the most common continuous baseline level of acoustic energy in a frequency window and in a time bin. It was developed by Towsey 2017 using the Lamel et al 1981 algorithm.
+#' The metric is calculated by taking the modal value of intensity values in temporal bin c in frequency window f of a reconding:
 #'
 #'\deqn{BGN_{f} = mode(dB_{cf})}
 #'
@@ -22,6 +23,8 @@
 #'
 #'\deqn{POW_{f} = max(dB_{cf}) - BGN_{cf}}
 #'
+#' This mean we'll have a value of BGN and POW to each frequency window of a recording.
+#'
 #' @references
 #' Towsey, M. W. (2017). The calculation of acoustic indices derived from long-duration recordings of the natural environment. In eprints.qut.edu.au. https://eprints.qut.edu.au/110634/
 #' <br>Lamel, L., Rabiner, L., Rosenberg, A., & Wilpon, J. (1981). An improved endpoint detector for isolated word recognition. IEEE Transactions on Acoustics, Speech, and Signal Processing, 29(4), 777-785 https://doi.org/10.1109/TASSP.1981.1163642
@@ -66,64 +69,83 @@
 #' bgn <- bgNoise(wave)
 #'
 #' # Print the results
-#' head(bgn$mono$BGN)
-#' head(bgn$mono$POW)
+#' head(bgn$values$mono$BGN)
+#' head(bgn$values$mono$POW)
 #'
 #' # Plotting background noise and soundscape profile for the first minute of the recording
 #' par(mfrow = c(2,2))
-#' plot(x = bgn$mono$BGN$BGN1, y = seq(1,bgn$sampRate, length.out = 256),
+#' plot(x = bgn$values$mono$BGN$BGN1, y = seq(1,bgn$sampRate, length.out = 256),
 #'      xlab = "Background Noise (dB)", ylab = "Frequency (hz)",
 #'      main = "BGN by Frequency",
 #'      type = "l")
-#' plot(x = bgn$mono$POW$POW1, y = seq(1,bgn$sampRate, length.out = 256),
+#' plot(x = bgn$values$mono$POW$POW1, y = seq(1,bgn$sampRate, length.out = 256),
 #'      xlab = "Soundscape Power (dB)", ylab = "Frequency (hz)",
 #'      main = "POW by Frequency",
 #'      type = "l")
-#' plot(bgn$mono$BGN$BGN1~bgn$mono$POW$POW1, pch = 16,
+#' plot(bgn$values$mono$BGN$BGN1~bgn$values$mono$POW$POW1, pch = 16,
 #'      xlab = "Soundscape Power (dB)", ylab = "Background Noise (dB)",
 #'      main = "BGN~POW")
-#' hist(bgn$mono$BGN$BGN1, main = "Histogram of BGN distribution",
+#' hist(bgn$values$mono$BGN$BGN1, main = "Histogram of BGN distribution",
 #'       xlab = "Background Noise (BGN)")
 #'
 #'\donttest{
-#'   oldpar <- par(no.readonly = TRUE)
-#'   ### This is a secondary example using audio from a real soundscape
-#'   ### These audios are originated from the Escutadô Project
-#'   # Getting audiofile from the online Zenodo library
-#'   dir <- tempdir()
-#'   rec <- paste0("GAL24576_20250401_", sprintf("%06d", 0),".wav")
-#'   recDir <- paste(dir,rec , sep = "/")
-#'   url <- paste0("https://zenodo.org/records/17575795/files/", rec, "?download=1")
+#' oldpar <- par(no.readonly = TRUE)
+#' ### This is a secondary example using audio from a real soundscape
+#' ### These audios are originated from the Escutadô Project
+#' # Getting audiofile from the online Zenodo library
+#' dir <- paste(tempdir(), "forExample", sep = "/")
+#' dir.create(dir)
+#' rec <- paste0("GAL24576_20250401_", sprintf("%06d", 0), ".wav")
+#' recDir <- paste(dir, rec , sep = "/")
+#' url <- paste0("https://zenodo.org/records/17575795/files/",
+#'               rec,
+#'               "?download=1")
 #'
-#'   # Downloading the file, might take some time denpending on your internet
-#'   download.file(url, destfile = recDir, mode = "wb")
+#' # Downloading the file, might take some time denpending on your internet
+#' download.file(url, destfile = recDir, mode = "wb")
 #'
-#'   # Running the bgNoise function with all the default arguments
-#'   bgn <- bgNoise(recDir)
+#' # Running the bgNoise function with all the default arguments
+#' bgn <- bgNoise(recDir)
 #'
-#'   # Print the results
-#'   head(bgn$left$BGN)
-#'   head(bgn$left$POW)
+#' # Print the results
+#' head(bgn$values$left$BGN)
+#' head(bgn$values$left$POW)
 #'
-#'   # Plotting background noise and soundscape profile for the first minute of the recording
-#'   par(mfrow = c(2,2))
-#'   plot(x = bgn$left$BGN$BGN1, y = seq(1,bgn$sampRate, length.out = 256),
-#'        xlab = "Background Noise (dB)", ylab = "Frequency (hz)",
-#'        main = "BGN by Frequency",
-#'        type = "l")
-#'   plot(x = bgn$left$POW$POW1, y = seq(1,bgn$sampRate, length.out = 256),
-#'        xlab = "Soundscape Power (dB)", ylab = "Frequency (hz)",
-#'        main = "POW by Frequency",
-#'        type = "l")
-#'   plot(bgn$left$BGN$BGN1~bgn$left$POW$POW1, pch = 16,
-#'        xlab = "Soundscape Power (dB)", ylab = "Background Noise (dB)",
-#'        main = "BGN~POW in left ear")
-#'   plot(bgn$right$BGN$BGN1~bgn$right$POW$POW1, pch = 16,
-#'        xlab = "Soundscape Power (dB)", ylab = "Background Noise (dB)",
-#'        main = "BGN~POW in right ear")
+#' # Plotting background noise and soundscape profile for the first minute of the recording
+#' par(mfrow = c(2, 2))
+#' plot(
+#'   x = bgn$values$left$BGN$BGN1,
+#'   y = seq(1, bgn$sampRate, length.out = 256),
+#'   xlab = "Background Noise (dB)",
+#'   ylab = "Frequency (hz)",
+#'   main = "BGN by Frequency",
+#'   type = "l"
+#' )
+#' plot(
+#'   x = bgn$values$left$POW$POW1,
+#'   y = seq(1, bgn$sampRate, length.out = 256),
+#'   xlab = "Soundscape Power (dB)",
+#'   ylab = "Frequency (hz)",
+#'   main = "POW by Frequency",
+#'   type = "l"
+#' )
+#' plot(
+#'   bgn$values$left$BGN$BGN1 ~ bgn$values$left$POW$POW1,
+#'   pch = 16,
+#'   xlab = "Soundscape Power (dB)",
+#'   ylab = "Background Noise (dB)",
+#'   main = "BGN~POW in left ear"
+#' )
+#' plot(
+#'   bgn$values$right$BGN$BGN1 ~ bgn$values$right$POW$POW1,
+#'   pch = 16,
+#'   xlab = "Soundscape Power (dB)",
+#'   ylab = "Background Noise (dB)",
+#'   main = "BGN~POW in right ear"
+#' )
 #'
-#'   unlink(recDir)
-#'   par(oldpar)
+#' unlink(dir, recursive = TRUE)
+#' par(oldpar)
 #'}
 bgNoise <- function(soundfile,
                     channel = "stereo",
@@ -138,6 +160,12 @@ bgNoise <- function(soundfile,
     stop("Please provide a valid channel: 'left', 'right', 'stereo', or 'mono'.")
   }
 
+  if(!(histbreaks %in% c("FD", "Sturges", "scott"))) {
+    if(!is.numeric(histbreaks)) {
+      stop("histbreaks must be 'FD', 'Sturges', 'scott' or a numeric value")
+    }
+  }
+
   audio <- if (is.character(soundfile)) {
     fileExt <- tolower(tools::file_ext(soundfile))
     if (fileExt %in% c("mp3", "wav")) {
