@@ -2,7 +2,7 @@
 #'
 #' @param soundfile tuneR Wave object or path to a valid audio
 #' @param channel channel where the background noise values will be extract from. Available channels are: `"stereo"`, `"mono"`, `"left"` or `"right"`. Defaults to `"stereo"`.
-#' @param timeBin size (in seconds) of the time bin. Defaults to `60`.
+#' @param timeBin size (in seconds) of the time bin. Set to `NULL` to use the entire audio as a single bin. Defaults to `60`
 #' @param dbThreshold minimum allowed value of dB for the spectrograms. Defaults to `-90`, as set by Towsey 2017.
 #' @param targetSampRate sample rate of the audios. Defaults to `NULL` to not change the sample rate. This argument is only used to down sample the audio.
 #' @param wl window length of the spectrogram. Defaults to `512`.
@@ -12,10 +12,11 @@
 #' <br>Can also be set to any number to limit or increase the amount of breaks.
 #' @param powthr a single value to evaluate the activity matrix for Soundscape Power (in %dB). Defaults to `10`.
 #' @param bgnthr a single value to evaluate the activity matrix for Background Noise (in %). Defaults to `0.8`
+#' @param beta how BGN thresholds are calculated. If TRUE, BGN thresholds are computed using all recordings combined.
 #'
 #' @export
-#' @returns A data frame containing the saturation values for all time bins of the inputed file
-#' @details  Soundscape Saturation (`SAT`) is a measure of the proportion of frequency bins that are acoustically active in a determined window of time. It was developed by Burivalova et al. 2017 as an index to test the acoustic niche hypothesis.
+#' @returns A vector containing the saturation values for all time bins of the inputted file
+#' @details  Soundscape Saturation (`SAT`) is a measure of the proportion of frequency bins that are acoustically active in a determined window of time. It was developed by Burivalova et al. 2018 as an index to test the acoustic niche hypothesis.
 #' To calculate this function, first we need to generate an activity matrix for each time bin of your recording with the following formula:
 #'
 #'\deqn{a_{mf} = 1\  if (BGN_{mf} > \theta_{1})\  or\  (POW_{mf} > \theta_{2});\  otherwise,\  a_{mf} = 0,}
@@ -28,64 +29,61 @@
 #'
 #'Since this is analyzing the soundscape saturaion of a single file, no normality tests will be done.
 #'
-#'@references Burivalova, Z., Towsey, M., Boucher, T., Truskinger, A., Apelis, C., Roe, P., & Game, E. T. (2017). Using soundscapes to detect variable degrees of human influence on tropical forests in Papua New Guinea. Conservation Biology, 32(1), 205-215. https://doi.org/10.1111/cobi.12968
+#'@references Burivalova, Z., Towsey, M., Boucher, T., Truskinger, A., Apelis, C., Roe, P., & Game, E. T. (2018). Using soundscapes to detect variable degrees of human influence on tropical forests in Papua New Guinea. Conservation Biology, 32(1), 205-215. https://doi.org/10.1111/cobi.12968
 #'
 #' @examples
 #'
-#'### Generating an artificial audio for the example
+#' oldpar <- par(no.readonly = TRUE)
+#'
+#' ### Generating an artificial audio for the example
 #' ## For this example we'll generate a sweep in a noisy soundscape
 #' library(tuneR)
 #'
-#' # Define the audio sample rate, duration and number of samples
+#' # Define parameters for the artificial audio
 #' samprate <- 12050
 #' dur <- 59
+#' n <- samprate * dur
 #'
-#' # Create a time vector
-#' t <- seq(0, dur, by = 1/samprate)
-#'
-#' # It starts at the frequency 50hz and goes all the way up to 4000hz
-#' # The sweep is exponnential
-#' freqT <- 50 * (4000/50)^(t/dur)
-#'
-#' # Generate the signal
-#' signal1 <- sin(10 * pi * cumsum(freqT) / samprate)
-#' # We create an envelope to give the sweep a fade away
-#' envelope <- exp(-4 * t / dur)
-#' # Generating low noise for the audio
+#' # White noise
 #' set.seed(413)
-#' noise <- rnorm(length(t), sd = 0.3)
-#' # Adding everything together in our signal
-#' signal <- signal1 * envelope + noise
+#' noise <- rnorm(n)
 #'
-#' # Normalize to 16-bit WAV range to create our Wave object
-#' signalNorm <- signal / max(abs(signal))
-#' wave_obj <- Wave(left = signalNorm, samp.rate = samprate, bit = 16)
+#' # Linear fade-out envelope
+#' fade <- seq(1, 0, length.out = n)
 #'
-#' # Now we calculate soundscape saturation for our audio
-#' # Here we are using timeBin = 10 so we get Soundscape Saturation values
-#' # every 10 seconds on the audio
-#' SAT <- singleSat(wave_obj, timeBin = 10)
+#' # Apply fade
+#' signal <- noise * fade
+#'
+#' # Create Wave object
+#' wave <- Wave(
+#'   left = signal,
+#'   samp.rate = samprate,
+#'   bit = 16
+#' )
+#'
+#' # Running singleSat() on the artificial audio
+#' sat <- singleSat(wave, timeBin = 10)
 #'
 #' # Now we can plot the results
 #' # In the left we have a periodogram and in the right saturaion values
 #' # along one minute
 #' par(mfrow = c(1,2))
-#' image(periodogram(wave_obj, width = 64), xlab = "Time (s)",
-#' ylab = "Frequency (hz)", log = "y", axes = FALSE)
+#' image(periodogram(wave, width = 8192, normalize = FALSE), xlab = "Time (s)",
+#' ylab = "Frequency (hz)", axes = FALSE)
 #' axis(1, labels = seq(0,60, 10), at = seq(0,7e5,length.out = 7))
 #' axis(2)
-#' plot(SAT$mono, xlab = "Time (s)", ylab = "Soundscape Saturation (%)",
+#' plot(sat, xlab = "Time (s)", ylab = "Soundscape Saturation (%)",
 #' type = "b", pch = 16, axes = FALSE)
 #' axis(1, labels = paste0(c("0-10","10-20","20-30","30-40","40-50","50-59"),
 #' "s"), at = 1:6)
 #' axis(2)
 #'
-#'\donttest{
+#' par(oldpar)
 #'
-#'oldpar <- par(no.readonly = TRUE)
-#'
-#'# Getting audiofile from the online Zenodo library
-#' dir <- tempdir()
+#' \donttest{
+#' # Getting audiofile from the online Zenodo library
+#' dir <- paste(tempdir(), "forExample", sep = "/")
+#' dir.create(dir)
 #' rec <- paste0("GAL24576_20250401_", sprintf("%06d", 0),".wav")
 #' recDir <- paste(dir,rec , sep = "/")
 #' url <- paste0("https://zenodo.org/records/17575795/files/", rec, "?download=1")
@@ -94,18 +92,16 @@
 #' download.file(url, destfile = recDir, mode = "wb")
 #'
 #' # Now we calculate soundscape saturation for both sides of the recording
-#' sat <- singleSat(recDir, wl = 256)
+#' sat <- singleSat(recDir)
 #'
 #' # Printing the results
 #' print(sat)
 #'
-#' barplot(c(sat$left, sat$right), col = c("darkgreen", "red"),
+#' barplot(sat, col = c("darkgreen", "red"),
 #'        names.arg = c("Left", "Right"), ylab = "Soundscape Saturation (%)")
 #'
-#' unlink(recDir)
-#' par(oldpar)
+#' unlink(dir, recursive = TRUE)
 #' }
-
 singleSat <- function(soundfile,
                       channel = "stereo",
                       timeBin = 60,
@@ -116,7 +112,22 @@ singleSat <- function(soundfile,
                       overlap = ceiling(length(window) / 2),
                       histbreaks = "FD",
                       powthr = 10,
-                      bgnthr = 0.8) {
+                      bgnthr = 0.8,
+                      beta = TRUE) {
+  if (!(channel %in% c("left", "right", "stereo", "mono")))
+    stop("channel must be 'stereo', 'mono', 'left', or 'right'")
+
+  if (!is.numeric(timeBin))
+    stop("timeBin must be numeric")
+
+  if (!is.numeric(dbThreshold))
+    stop("timeBin must be numeric")
+
+  if (!is.null(targetSampRate)) {
+    if (!is.numeric(targetSampRate))
+      stop("targetSampRate must be either NULL or a numeric value")
+  }
+
   halfWl <- round(wl / 2)
 
   BGNPOW <- bgNoise(
@@ -131,64 +142,38 @@ singleSat <- function(soundfile,
     histbreaks = histbreaks
   )
 
+  nBins <- length(BGNPOW$timeBins)
+
   if (BGNPOW$channel == "stereo") {
-    BGNsaturation <- sapply(c("left", "right"), function(side) {
-      list(apply(BGNPOW[[side]]$BGN, 2, function(BGN) {
-        Q <- quantile(BGN, bgnthr)
-        BGN > Q
-      }))
-    })
+    BGN <- cbind(BGNPOW$values$left$BGN, BGNPOW$values$right$BGN)
+    names <- paste0(rep(c("left", "right"), each = nBins), seq(nBins))
+  } else {
+    BGN <- BGNPOW$values[[BGNPOW$channel]]$BGN
+    names <- paste0(rep(BGNPOW$channel, nBins), seq(nBins))
+  }
 
-    POWsaturation <- sapply(c("left", "right"), function(side) {
-      list(apply(BGNPOW[[side]]$POW, 2, function(POW) {
-        POW > powthr
-      }))
-    })
+  if (BGNPOW$channel == "stereo") {
+    POW <- cbind(BGNPOW$values$left$POW, BGNPOW$values$right$POW)
+  } else {
+    POW <- BGNPOW$values[[BGNPOW$channel]]$POW
+  }
 
-    singSat <- as.data.frame(do.call(cbind, sapply(c("left", "right"), function(side) {
-      list(sapply(1:length(BGNPOW$timeBins), function(i) {
-        sum(BGNsaturation[[side]][, i] |
-              POWsaturation[[side]][, i]) / halfWl
-      }))
-    })))
+  if (beta) {
+    BGNQ <- quantile(unlist(BGN), bgnthr)
 
-  } else if (BGNPOW$channel == "mono") {
-    BGNsaturation <- list(mono = apply(BGNPOW$mono$BGN, 2, function(BGN) {
-      Q <- quantile(BGN, bgnthr)
-      BGN > Q
-    }))
-
-    POWsaturation <- list(mono = apply(BGNPOW$mono$POW, 2, function(POW) {
-      POW > powthr
-    }))
-
-    singSat <- data.frame("mono" = do.call(cbind, list(sapply(1:length(BGNPOW$timeBins), function(i) {
-      sum(BGNsaturation$mono[, i] |
-            POWsaturation$mono[, i]) / halfWl
-    }))))
+    singSat <- colMeans(BGN > BGNQ | POW > powthr)
 
   } else {
-    realChannel <- c("left", "right")[c("left", "right") %in% names(BGNPOW)]
+    singSat <- sapply(1:ncol(BGN), function(t) {
+      sum(BGN[, t] > quantile(BGN[, t], bgnthr) |
+            POW[, t] > powthr) / halfWl
 
-    BGNsaturation <- list(apply(BGNPOW[[realChannel]]$BGN, 2, function(BGN) {
-      Q <- quantile(BGN, bgnthr)
-      BGN > Q
-    })) |>
-      setNames(realChannel)
-
-    POWsaturation <- list(apply(BGNPOW[[realChannel]]$POW, 2, function(POW) {
-      POW > powthr
-    })) |>
-      setNames(realChannel)
-
-    singSat <- data.frame(do.call(cbind, list(sapply(1:length(BGNPOW$timeBins), function(i) {
-      sum(BGNsaturation[[realChannel]][, i] |
-            POWsaturation[[realChannel]][, i]) / halfWl
-    })))) |>
-      setNames(realChannel)
+    })
 
   }
 
-  singSat
+  names(singSat) <- names
+
+  return(singSat)
 
 }
